[mkdocs]: https://github.com/mkdocs/mkdocs
[mkdocs-material]: https://github.com/squidfunk/mkdocs-material
[pymdown-extensions]: https://github.com/facelessuser/pymdown-extensions
[wxpython]: https://pypi.python.org/pypi/wxPython/
